Constants class
constant class is used to keep the constant error messages.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- emailRegex ↔ RegExp
-
getter/setter pair
- passwordRegex ↔ RegExp
-
getter/setter pair
- urlRegex ↔ RegExp
-
getter/setter pair
Constants
- alphabetPhoneNumberErrorMessage → const String
- emptyEmailErrorMessage → const String
- emptyPasswordErrorMessage → const String
- emptyPhoneNumberErrorMessage → const String
- emptyTextErrorMessage → const String
- emptyUrlErrorMessage → const String
- invalidEmailErrorMessage → const String
- invalidPasswordErrorMessage → const String
- invalidUrlErrorMessage → const String
- lowerCasePasswordErrorMessage → const String
- maxLengthErrorMessage → const String
- maxPasswordLengthErrorMessage → const String
- maxPhoneNumberLengthErrorMessage → const String
- minLengthErrorMessage → const String
- minPasswordLengthErrorMessage → const String
- numberPasswordErrorMessage → const String
- specialPasswordErrorMessage → const String
- upperCasePasswordErrorMessage → const String